#
# spec file for package kubeone
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%define KUBERNETES_STABLE_VERSION v1.28.6

%define __arch_install_post export NO_BRP_STRIP_DEBUG=true

Name:           kubeone
Version:        1.8.3
Release:        1.1
Summary:        CLI for the kubeone cluster automation
License:        Apache-2.0
URL:            https://github.com/kubermatic/kubeone
Source:         kubeone-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  go >= 1.22

%description
Kubermatic KubeOne automates cluster operations on all your cloud, on-prem, edge, and IoT environments. KubeOne can install high-available (HA) master clusters as well single master clusters.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1

%build
DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags=" \
   -X k8c.io/kubeone/pkg/cmd.defaultKubeVersion=%{KUBERNETES_STABLE_VERSION} \
   -X k8c.io/kubeone/pkg/cmd.version=%{version} \
   -X k8c.io/kubeone/pkg/cmd.commit=v%{version} \
   -X k8c.io/kubeone/pkg/cmd.date=$BUILD_DATE" \
   -o bin/kubeone

%install
# Install the binary.
install -D -m 0755 bin/%{name} "%{buildroot}/%{_bindir}/%{name}"

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh_completion.d/
%{buildroot}/%{_bindir}/%{name} completion zsh > %{buildroot}%{_datarootdir}/zsh_completion.d/_%{name}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%files -n %{name}-bash-completion
%dir %{_datarootdir}/bash-completion/completions/
%{_datarootdir}/bash-completion/completions/%{name}

%files -n %{name}-zsh-completion
%defattr(-,root,root)
%dir %{_datarootdir}/zsh_completion.d/
%{_datarootdir}/zsh_completion.d/_%{name}

%changelog
* Sat Sep 21 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.8.3:
  * Add changelog for v1.8.3 (#3381)
  * Update vSphere images to use our mirror (#3378)
  * Replace deprecated Hetzner (in fact, restricted) cx21 instance
    type with cx22 (#3371)
  * [release/v1.8] Synchronize OWNERS_ALIASES file with Github
    teams (#3363)
* Fri Aug  9 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.8.2:
  * Add changelog for v1.8.2 (#3341)
  * Remove centos7 e2e tests (#3335)
  * CentOS docker repo being abandoned, replaced with RHEL (#3336)
  * [release/v1.8] Update machine-controller to 1.59.3 (#3323)
  * Set HttpPutResponseHopLimit to 3 by default for AWS nodes
    (#3329)
  * [release/v1.8] Update calico CNI to fix CPU issues (#3326)
  * Minor fix to the cluster autoscaler docs (#3315)
  * Allow upstream cluster autoscaler flags configuration (#3306)
  * do not put multiple identical tolerations on the CoreDNS
    deployment (#3298)
* Wed Jul  3 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.8.1:
  * Add release date for 1.8.1 (#3294)
  * Remove release date for 1.8.1 (#3292)
  * Add changelog for v1.8.1 (#3288)
  * Don't downgrade GCP CCM for v1.27 clusters (#3284)
  * Bind csi-snapshotter to v8.0.1 for GCE (#3281)
  * Documentation for VMware Cloud Director (#3278)
  * Be explicit about bastion type, as not OSes support nano size
    (#3276)
  * [release/v1.8] Fix snapshot-webhook admitting non-supported
    objects and add default VolumeSnapshotClass for all supported
    providers (#3275)
  * Fix openstack CCM addon (#3274)
  * Bind csi-snapshotter to v8.0.1 (#3270)
  * fix local helm releases deletion issue (#3268)
  * Increase TEST_TIMEOUT to 90m for stable tests infrastructure
    (#3267)
  * [release/v1.8] Use the same bastion_type on AWS as worker_type
    (#3264)
  * Fix default rockylinux EC2 image filter query (#3262)
  * Refactor the upgrade process to stop using config on upgrade
    (#3253)
  * change order of ensureCABundleConfigMap task (#3247)
  * [release/v1.8] Improve the Kubernetes 1.30 support (#3242)
  * [release/v1.8] bump GCP CCM to 30.x, using staging images
    (#3241)
  * install apparmor-utils in ubuntu (#3235)
  * [release/v1.8] Update images to support Kubernetes 1.30 (#3230)
  * [release/v1.8] Kubernetes 1.30 support (#3215)
  * Update canal to v3.27.3 (#3200)
* Tue May 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.8.0:
  Urgent Upgrade Notes
  (No, really, you MUST read this before you upgrade)
  * Refactor example Terraform configs for Hetzner to randomly
    generate the private network subnet in order to support
    creating multiple KubeOne clusters (#3152, @xmudrii)
  * The example Terraform configs for Azure have been migrated to
    use the Standard SKU for IP addresses. This is a breaking
    change for existing setups; in which case you should continue
    using your current SKU. Manual migration is possible by
    dissociating IP from the VM and LB, the migrating it, and
    assigning it back, however please consider all potential risks
    before doing this migration (#3149, @kron4eg)
  * Credentials defined in the credentials file now have precedence
    over credentials defined via environment variables. This change
    is made to match the behavior that's already documented in the
    KubeOne docs. If you use both the credentials file and the
    environment variables, we recommend double-checking your
    credentials file to make sure the credentials are up to date,
    as those credentials will be applied on the next kubeone apply
    run (#2991, @kron4eg)
  * kured has been removed, you have to re-enable it back in form
    of helmRelease (#3024, @kron4eg)
  * OSM: The latest Ubuntu 22.04 images on Azure have modified the
    configuration for cloud-init and how it accesses its datasource
    in Azure, in a breaking way. If you're having an Azure cluster,
    it's required to refresh your machines with the latest provided
    OSPs to ensure that a system-wide package update doesn't result
    in broken machines. (#3172, @xrstf)
  * Support for Docker is removed; containerRuntime.docker became a
    no-op. (#3008, @kron4eg)
* Thu May  2 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.7.4:
  * CHANGELOG: Add changelog for v1.7.4 (#3168)
  * [release/v1.7] bump OSM to 1.3.5 (#3163)
  * [release/v1.7] Clean `yum` caches when configuring repos
    (#3147)
  * [release/v1.7] fix: debian apt-get update running before
    configuring repositories (#3084)
  * Deploy User defined addons before external CCM initialization
    (#3068)
  * Update MC to v1.57.6 (#3064)
* Sat Mar 16 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.7.3:
  * Add changelog for v1.7.3 (#3063)
  * Update Go to 1.21.6 (#3060)
  * Update machine-controller to v1.57.5 (#3057)
  * Improve error messaging when working with remote files over SSH
    (#3054)
  * [release/v1.7]  Fix Flatcar torcx issues (#3041)
  * fix strictArp field usage (#3006)
  * Define fixed etcd versions (#3004)
  * Fix helm deploying resources in the wrong namespace (#3001)
* Mon Jan 29 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package kubeone: CLI for the kubeone cluster automation
